set more off

/*generate tables*/

use "senate-demos.dta",clear

/*Table 1, column 1*/

reg dwnom108_1 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap, cluster(icpsrid)

/*Table 1, column 2*/

reg dwnom108_1 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap dempresidentialvote gop, cluster(icpsrid)

/*Table 1, column 3*/

reg dwnom108_2 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap, cluster(icpsrid)

/*Table 1, column 4*/

reg dwnom108_2 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap dempresidentialvote gop, cluster(icpsrid)


/*estimate model fit statistics and coefficients for figures*/

quietly gen demos1=0
quietly gen withparty1=0
quietly gen withparty2=0
quietly gen demos2=0
quietly gen nosouthr2=0
quietly gen southr2=0
quietly gen dw1gop=0
quietly gen dw1gopmin=0
quietly gen dw1gopmax=0
quietly gen dw2gop=0
quietly gen dw2gopmin=0
quietly gen dw2gopmax=0

gen region=floor(sc/10)
gen south=0 
quietly replace south=1 if region==4 | sc==51 | sc==54 | sc==34

forval j=73/108	{
			quietly reg dwnom108_1 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap if cong==`j'
			local km=e(r2_a)
			quietly replace demos1=`km' if cong==`j'
			quietly reg dwnom108_1 gop age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap dempresidentialvote if cong==`j'
			local br2=e(r2_a)
			quietly replace withparty1=`br2' if cong==`j'
			
			quietly reg dwnom108_1 gop age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap dempresidentialvote if cong==`j'
			local b=_b[gop]
			local se=_se[gop]
			quietly replace dw1gop=`b' if cong==`j'
			quietly replace dw1gopmin=`b'-(2*`se') if cong==`j'
			quietly replace dw1gopmax=`b'+(2*`se') if cong==`j'
			
			quietly reg dwnom108_2 gop age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap dempresidentialvote if cong==`j'
			local b=_b[gop]
			local se=_se[gop]
			quietly replace dw2gop=`b' if cong==`j'
			quietly replace dw2gopmin=`b'-(2*`se') if cong==`j'
			quietly replace dw2gopmax=`b'+(2*`se') if cong==`j'
			
			quietly reg dwnom108_2 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap if cong==`j'
			local dr2=e(r2_a)
			quietly replace demos2=`dr2' if cong==`j'
			
			quietly reg dwnom108_2 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap if south==0 & cong==`j'
			local dr2=e(r2_a)
			quietly replace nosouthr2=`dr2' if cong==`j'
			
			quietly reg dwnom108_2 age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap if south==1 & cong==`j'
			local dr2=e(r2_a)
			quietly replace southr2=`dr2' if cong==`j'
			
			quietly reg dwnom108_2 gop age65 black farmer finance forborn gvtwrkr manuf logpop urban popsqmi logpercap dempresidentialvote if cong==`j'
			local br2=e(r2_a)
			quietly replace withparty2=`br2' if cong==`j'
			}


/*collapse by Congress*/

collapse (mean) demos1 withparty1 withparty2 demos2 nosouthr2 southr2 dw1gop dw1gopmin dw1gopmax dw2gop dw2gopmin dw2gopmax,by(cong)


/*make figures*/

gen counter=cong-73
gen congyear=cong+1860+counter

/*Figure 1*/

twoway (connected demos1 congyear) (connected demos2 congyear), /// 
       legend(label(1 "demographics->DW1") label(2 "demographics->DW2") size("small")) /// 
       ytitle("Adjusted R2", size(small)) ylabel(, labstyle(small_body) angle(horizontal)) /// 
       xlabel(1933(10)2003, labstyle(small_body)) xtick(1933(2)2003) xtitle("Congress start year", size(small) m(medsmall)) scheme(s1mono)

/*Figure 2*/

twoway (connected withparty1 congyear) (connected withparty2 congyear), /// 
       legend(label(1 "demographics," "presidential vote," "party->DW1") label(2 "demographics," "presidential vote," "party->DW2") size("small")) /// 
       xlabel(1933(10)2003, labstyle(small_body)) xtick(1933(2)2003) xtitle("Congress start year", size(small) m(medsmall)) /// 
       ytitle("Adjusted R2", size(small)) ylabel(, labstyle(small_body) angle(horizontal)) scheme(s1mono)

/*Figure 3*/

twoway (rcap dw1gopmin dw1gopmax congyear) (connected dw1gop congyear) /// 
       (rcap dw2gopmin dw2gopmax congyear) (connected dw2gop congyear), /// 
       ytitle(Coefficient with 95% confidence intervals, height(5) size(small)) ylabel(, labstyle(small_body) angle(horizontal)) /// 
       xlabel(1933(10)2003, labstyle(small_body)) xtick(1933(2)2003) xtitle("Congress start year", size(small) m(medsmall))  /// 
       legend(label(2 "Party coefficient: DW1") label(4 "Party coefficient: DW2") size("small") order(2 4)) scheme(s1mono)

/*Figure 4*/

twoway (connected nosouthr2 congyear) (connected southr2 congyear), ///  
       legend( label(1 "Non-South: demographics->DW2") label(2 "South: demographics->DW2")size("small")) /// 
       ytitle("Adjusted R2", size(small)) ylabel(, labstyle(small_body) angle(horizontal)) /// 
       xlabel(1933(10)2003, labstyle(small_body)) xtick(1933(2)2003) xtitle("Congress start year", size(small) m(medsmall))  scheme(s1mono)







